@@ -957,11 +957,12 @@ get_option (ppd_option_t *option)
 {
 	GnomeCupsPrinterOption *ret;
 	int i;
+	char *defchoice;
+	char *p;
 	
 	ret = g_new0 (GnomeCupsPrinterOption, 1);
 	ret->id = g_strdup (option->keyword);
 	ret->text = g_strdup (option->text);
-	ret->value = g_strdup (option->defchoice);
 	ret->type = option->ui;
 	ret->n_choices = option->num_choices;
 	ret->choices = g_new0 (GnomeCupsPrinterOptionChoice, ret->n_choices);
@@ -970,6 +971,18 @@ get_option (ppd_option_t *option)
 		ret->choices[i].text = g_strdup (option->choices[i].text);
 	}
 
+	defchoice = g_strdup (option->defchoice);
+	
+	/* Strip trailing spaces and tabs since CUPS doesn't does this
+	 */
+	p = defchoice + strlen (defchoice);
+	while (p > defchoice &&
+	       (*(p - 1) == ' ' || *(p - 1) == '\t')) {
+		*(p - 1) = '\0';
+		p--;
+	}
+	ret->value = defchoice;
+
 	return ret;
 }
 
